@@ -40,7 +40,7 @@ class GitTree(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._sha)
-        return self._NoneIfNotSet(self._sha)
+        return self._sha.value
 
     @property
     def tree(self):
@@ -48,7 +48,7 @@ class GitTree(github.GithubObject.CompletableGithubObject):
         :type: list of :class:`github.GitTreeElement.GitTreeElement`
         """
         self._completeIfNotSet(self._tree)
-        return self._NoneIfNotSet(self._tree)
+        return self._tree.value
 
     @property
     def url(self):
@@ -56,7 +56,7 @@ class GitTree(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._url)
-        return self._NoneIfNotSet(self._url)
+        return self._url.value
 
     @property
     def _identity(self):
@@ -69,14 +69,8 @@ class GitTree(github.GithubObject.CompletableGithubObject):
 
     def _useAttributes(self, attributes):
         if "sha" in attributes:  # pragma no branch
-            assert attributes["sha"] is None or isinstance(attributes["sha"], (str, unicode)), attributes["sha"]
-            self._sha = attributes["sha"]
+            self._sha = self._makeStringAttribute(attributes["sha"])
         if "tree" in attributes:  # pragma no branch
-            assert attributes["tree"] is None or all(isinstance(element, dict) for element in attributes["tree"]), attributes["tree"]
-            self._tree = None if attributes["tree"] is None else [
-                github.GitTreeElement.GitTreeElement(self._requester, self._headers, element, completed=False)
-                for element in attributes["tree"]
-            ]
+            self._tree = self._makeListOfClassesAttribute(github.GitTreeElement.GitTreeElement, attributes["tree"])
         if "url" in attributes:  # pragma no branch
-            assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
-            self._url = attributes["url"]
+            self._url = self._makeStringAttribute(attributes["url"])
