@@ -312,9 +312,22 @@ class Github(object):
         )
         return data
 
+    def get_hook(self, name):
+        """
+        :calls: `GET /hooks/:name <http://developer.github.com/v3/repos/hooks/>`_
+        :param name: string
+        :rtype: :class:`github.HookDescription.HookDescription`
+        """
+        assert isinstance(name, (str, unicode)), name
+        headers, attributes = self.__requester.requestJsonAndCheck(
+            "GET",
+            "/hooks/" + name
+        )
+        return HookDescription.HookDescription(self.__requester, headers, attributes, completed=True)
+
     def get_hooks(self):
         """
-        :calls: `GET /hooks <http://developer.github.com/>`_
+        :calls: `GET /hooks <http://developer.github.com/v3/repos/hooks/>`_
         :rtype: list of :class:`github.HookDescription.HookDescription`
         """
         headers, data = self.__requester.requestJsonAndCheck(
@@ -346,6 +359,17 @@ class Github(object):
         )
         return GitignoreTemplate.GitignoreTemplate(self.__requester, headers, attributes, completed=True)
 
+    def get_emojis(self):
+        """
+        :calls: `GET /emojis <http://developer.github.com/v3/emojis/>`_
+        :rtype: dictionary of type => url for emoji`
+        """
+        headers, attributes = self.__requester.requestJsonAndCheck(
+            "GET",
+            "/emojis"
+        )
+        return attributes
+
     def create_from_raw_data(self, klass, raw_data, headers={}):
         """
         Creates an object from raw_data previously obtained by :attr:`github.GithubObject.GithubObject.raw_data`,
