@@ -9,6 +9,7 @@
 # Copyright 2012 Steve English <steve.english@navetas.com>                     #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Ed Jackson <ed.jackson@gmail.com>                             #
 # Copyright 2013 Jonathan J Hunt <hunt@braincorporation.com>                   #
 # Copyright 2013 Mark Roddy <markroddy@gmail.com>                              #
@@ -37,6 +38,8 @@ import base64
 import urllib
 import urlparse
 import sys
+import Consts
+import re
 
 atLeastPython26 = sys.hexversion >= 0x02060000
 atLeastPython3 = sys.hexversion >= 0x03000000
@@ -63,7 +66,66 @@ class Requester:
         cls.__httpConnectionClass = httplib.HTTPConnection
         cls.__httpsConnectionClass = httplib.HTTPSConnection
 
+    #############################################################
+    # For Debug
+    @classmethod
+    def setDebugFlag(cls, flag):
+        cls.DEBUG_FLAG = flag
+
+    @classmethod
+    def setOnCheckMe(cls, onCheckMe):
+        cls.ON_CHECK_ME = onCheckMe
+
+    DEBUG_FLAG = False
+
+    DEBUG_FRAME_BUFFER_SIZE = 1024
+
+    DEBUG_HEADER_KEY = "DEBUG_FRAME"
+
+    ON_CHECK_ME = None
+
+    def NEW_DEBUG_FRAME(self, requestHeader):
+        '''
+        Initialize a debug frame with requestHeader
+        Frame count is updated and will be attached to respond header
+        The structure of a frame: [requestHeader, statusCode, responseHeader, raw_data]
+        Some of them may be None
+        '''
+        if self.DEBUG_FLAG:  # pragma no branch (Flag always set in tests)
+            new_frame = [requestHeader, None, None, None]
+            if self._frameCount < self.DEBUG_FRAME_BUFFER_SIZE - 1:  # pragma no branch (Should be covered)
+                self._frameBuffer.append(new_frame)
+            else:
+                self._frameBuffer[0] = new_frame  # pragma no cover (Should be covered)
+
+            self._frameCount = len(self._frameBuffer) - 1
+
+    def DEBUG_ON_RESPONSE(self, statusCode, responseHeader, data):
+        '''
+        Update current frame with response
+        Current frame index will be attached to responseHeader
+        '''
+        if self.DEBUG_FLAG:  # pragma no branch (Flag always set in tests)
+            self._frameBuffer[self._frameCount][1:4] = [statusCode, responseHeader, data]
+            responseHeader[self.DEBUG_HEADER_KEY] = self._frameCount
+
+    def check_me(self, obj):
+        if self.DEBUG_FLAG and self.ON_CHECK_ME is not None:  # pragma no branch (Flag always set in tests)
+            frame = None
+            if self.DEBUG_HEADER_KEY in obj._headers:
+                frame_index = obj._headers[self.DEBUG_HEADER_KEY]
+                frame = self._frameBuffer[frame_index]
+            self.ON_CHECK_ME(obj, frame)
+
+    def _initializeDebugFeature(self):
+        self._frameCount = 0
+        self._frameBuffer = []
+
+    #############################################################
+
     def __init__(self, login_or_token, password, base_url, timeout, client_id, client_secret, user_agent, per_page):
+        self._initializeDebugFeature()
+
         if password is not None:
             login = login_or_token
             if atLeastPython3:
@@ -103,26 +165,28 @@ class Requester:
             'See http://developer.github.com/v3/#user-agent-required'
         self.__userAgent = user_agent
 
-    def requestJsonAndCheck(self, verb, url, parameters, input):
-        return self.__check(*self.requestJson(verb, url, parameters, input))
+    def requestJsonAndCheck(self, verb, url, parameters=None, headers=None, input=None, cnx=None):
+        return self.__check(*self.requestJson(verb, url, parameters, headers, input, cnx))
 
-    def requestMultipartAndCheck(self, verb, url, parameters, input):
-        return self.__check(*self.requestMultipart(verb, url, parameters, input))
+    def requestMultipartAndCheck(self, verb, url, parameters=None, headers=None, input=None):
+        return self.__check(*self.requestMultipart(verb, url, parameters, headers, input))
 
     def __check(self, status, responseHeaders, output):
         output = self.__structuredFromJson(output)
         if status >= 400:
-            raise self.__createException(status, output)
+            raise self.__createException(status, responseHeaders, output)
         return responseHeaders, output
 
-    def __createException(self, status, output):
-        if status == 401 and output["message"] == "Bad credentials":
+    def __createException(self, status, headers, output):
+        if status == 401 and output.get("message") == "Bad credentials":
             cls = GithubException.BadCredentialsException
-        elif status == 403 and output["message"].startswith("Missing or invalid User Agent string"):
+        elif status == 401 and 'x-github-otp' in headers and re.match(r'.*required.*', headers['x-github-otp']):
+            cls = GithubException.TwoFactorException
+        elif status == 403 and output.get("message").startswith("Missing or invalid User Agent string"):
             cls = GithubException.BadUserAgentException
-        elif status == 403 and output["message"].startswith("API Rate Limit Exceeded"):
+        elif status == 403 and output.get("message").startswith("API Rate Limit Exceeded"):
             cls = GithubException.RateLimitExceededException
-        elif status == 404 and output["message"] == "Not Found":
+        elif status == 404 and output.get("message") == "Not Found":
             cls = GithubException.UnknownObjectException
         else:
             cls = GithubException.GithubException
@@ -139,13 +203,13 @@ class Requester:
             except ValueError, e:
                 return {'data': data}
 
-    def requestJson(self, verb, url, parameters, input):
+    def requestJson(self, verb, url, parameters=None, headers=None, input=None, cnx=None):
         def encode(input):
             return "application/json", json.dumps(input)
 
-        return self.__requestEncode(verb, url, parameters, input, encode)
+        return self.__requestEncode(cnx, verb, url, parameters, headers, input, encode)
 
-    def requestMultipart(self, verb, url, parameters, input):
+    def requestMultipart(self, verb, url, parameters=None, headers=None, input=None):
         def encode(input):
             boundary = "----------------------------3c3ba8b523b2"
             eol = "\r\n"
@@ -159,14 +223,15 @@ class Requester:
             encoded_input += "--" + boundary + "--" + eol
             return "multipart/form-data; boundary=" + boundary, encoded_input
 
-        return self.__requestEncode(verb, url, parameters, input, encode)
+        return self.__requestEncode(None, verb, url, parameters, headers, input, encode)
 
-    def __requestEncode(self, verb, url, parameters, input, encode):
+    def __requestEncode(self, cnx, verb, url, parameters, requestHeaders, input, encode):
         assert verb in ["HEAD", "GET", "POST", "PATCH", "PUT", "DELETE"]
         if parameters is None:
             parameters = dict()
+        if requestHeaders is None:
+            requestHeaders = dict()
 
-        requestHeaders = dict()
         self.__authenticate(url, requestHeaders, parameters)
         requestHeaders["User-Agent"] = self.__userAgent
 
@@ -177,7 +242,9 @@ class Requester:
         if input is not None:
             requestHeaders["Content-Type"], encoded_input = encode(input)
 
-        status, responseHeaders, output = self.__requestRaw(verb, url, requestHeaders, encoded_input)
+        self.NEW_DEBUG_FRAME(requestHeaders)
+
+        status, responseHeaders, output = self.__requestRaw(cnx, verb, url, requestHeaders, encoded_input)
 
         if "x-ratelimit-remaining" in responseHeaders and "x-ratelimit-limit" in responseHeaders:
             self.rate_limiting = (int(responseHeaders["x-ratelimit-remaining"]), int(responseHeaders["x-ratelimit-limit"]))
@@ -187,10 +254,16 @@ class Requester:
         if "x-oauth-scopes" in responseHeaders:
             self.oauth_scopes = responseHeaders["x-oauth-scopes"].split(", ")
 
+        self.DEBUG_ON_RESPONSE(status, responseHeaders, output)
+
         return status, responseHeaders, output
 
-    def __requestRaw(self, verb, url, requestHeaders, input):
-        cnx = self.__createConnection()
+    def __requestRaw(self, cnx, verb, url, requestHeaders, input):
+        if cnx is None:
+            cnx = self.__createConnection()
+        else:
+            assert cnx == "status"
+            cnx = self.__httpsConnectionClass("status.github.com", 443)
         cnx.request(
             verb,
             url,
@@ -200,7 +273,7 @@ class Requester:
         response = cnx.getresponse()
 
         status = response.status
-        responseHeaders = dict(response.getheaders())
+        responseHeaders = dict((k.lower(), v) for k, v in response.getheaders())
         output = response.read()
 
         cnx.close()
@@ -244,7 +317,7 @@ class Requester:
             kwds["strict"] = True  # Useless in Python3, would generate a deprecation warning
         if atLeastPython26:  # pragma no branch (Branch useful only with Python 2.5)
             kwds["timeout"] = self.__timeout  # Did not exist before Python2.6
-        return self.__connectionClass(host=self.__hostname, port=self.__port, **kwds)
+        return self.__connectionClass(self.__hostname, self.__port, **kwds)
 
     def __log(self, verb, url, requestHeaders, input, status, responseHeaders, output):
         logger = logging.getLogger(__name__)
@@ -254,4 +327,6 @@ class Requester:
                     requestHeaders["Authorization"] = "Basic (login and password removed)"
                 elif requestHeaders["Authorization"].startswith("token"):
                     requestHeaders["Authorization"] = "token (oauth token removed)"
+                else:  # pragma no cover (Cannot happen, but could if we add an authentication method => be prepared)
+                    requestHeaders["Authorization"] = "(unknown auth removed)"  # pragma no cover (Cannot happen, but could if we add an authentication method => be prepared)
             logger.debug("%s %s://%s%s %s %s ==> %i %s %s", str(verb), self.__scheme, self.__hostname, str(url), str(requestHeaders), str(input), status, str(responseHeaders), str(output))
